FcoseGraph class final
A validated compound graph suitable for layout.
Constructors
-
FcoseGraph({required Iterable<
FcoseNode> nodes, Iterable<FcoseEdge> edges = const []})
Properties
-
childrenByParent
→ Map<
String?, List< FcoseNode> > -
latefinal
-
edges
→ List<
FcoseEdge> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
leafNodes
→ List<
FcoseNode> -
latefinal
-
nodeById
→ Map<
String, FcoseNode> -
latefinal
-
nodes
→ List<
FcoseNode> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited