Xorshift32 class final
Deterministic xorshift32 generator with JavaScript-compatible 32-bit steps.
Dart VM integers are not limited to 32 bits, so every operation is masked just as JavaScript bitwise operators truncate their operands.
Constructors
- Xorshift32(int seed)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
nextDouble(
) → double -
nextInt(
int maximum) → int -
nextUint32(
) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited